@@ -28,7 +28,8 @@
 
 #include "containmentinterface.h"
 #include "wallpaperinterface.h"
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+
+#if KDECLARATIVE_BUILD_DEPRECATED_SINCE(5, 89)
 #include <kdeclarative/configpropertymap.h>
 #else
 #include <KConfigPropertyMap>
@@ -49,6 +50,7 @@ AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariant
 {
     qmlRegisterAnonymousType<QAction>("org.kde.plasma.plasmoid", 1);
 
+    connect(applet()->containment()->corona(), &Plasma::Corona::editModeChanged, this, &AppletInterface::editModeChanged);
     connect(this, &AppletInterface::configNeedsSaving, applet(), &Plasma::Applet::configNeedsSaving);
     connect(applet(), &Plasma::Applet::immutabilityChanged, this, &AppletInterface::immutabilityChanged);
     connect(applet(), &Plasma::Applet::userConfiguringChanged, this, &AppletInterface::userConfiguringChanged);
@@ -140,7 +142,7 @@ void AppletInterface::init()
         return;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if KDECLARATIVE_BUILD_DEPRECATED_SINCE(5, 89)
     m_configuration = new KDeclarative::ConfigPropertyMap(applet()->configScheme(), this);
 #else
     m_configuration = new KConfigPropertyMap(applet()->configScheme(), this);
@@ -875,7 +877,7 @@ bool AppletInterface::eventFilter(QObject *watched, QEvent *event)
             // and set the event position as action data
             if (plugin->contextualActions().length() == 1) {
                 // but first check whether we are not a popup
-                // we don't want to randomly creates applets without confirmation
+                // we don't want to randomly create applets without confirmation
                 if (static_cast<QQuickItem *>(watched)->window() != ci->window()) {
                     return true;
                 }
@@ -924,4 +926,14 @@ KPluginMetaData AppletInterface::metaData() const
     return applet()->pluginMetaData();
 }
 
+AppletInterface *AppletInterface::self()
+{
+    return this;
+}
+
+bool AppletInterface::isEditMode() const
+{
+    return applet()->containment()->corona()->isEditMode();
+}
+
 #include "moc_appletinterface.cpp"
